/**
 * 
 * 个性化文件打点文件，只允许个性化提交代码。
 * 此文件禁止产品化底座提交。
 * 
 */
import $ from "@/common";

var service = {
  "view/trade-buy-avgr/trade-buy-avgr-form": {
    forceChangeCard(arg) {		//下单定投时是否跳转激活银行卡页面
      let currentCard = arg[0], cb = arg[1];
      if(currentCard.cardType === 'bank' && currentCard.isNetModifyBankAcco == '1') {
        $.confirm('您当前使用的银行卡未激活，请激活后再使用！', '去激活',()=>{
          $.route.hsOpen("add-bank/change-bank", currentCard, {useStorage: true});
        })
      } else {
        cb && cb();;
      }
	  	return '';
    }
  },
  "service/market/common": {
    /**
    * hsjj 要求不显示任期，故把接口中的任期字符手动置空
    * @param {array} arg 参数数组
    * @param {object} arg[0] 基金经理列表接口返回值
    */
    handleFundManager(arg) {
      let [ jsonResult ] = arg;
      
      if (jsonResult.list && jsonResult.list.length > 0) {
        jsonResult.list.forEach((manager) => {
          manager.performance = ""; // 回报数据置空
          if (manager.fundList) { // 可能还存在内置的数组，同样置空
            manager.fundList.forEach((item) => item.performance = "");
          }
        });
        // 因为产品化基金经理默认显示回报相关内容，即使数据置空也会以 -- 的形式显示回报，故额外添加一个标志
        jsonResult.showPerformance = false;
      }

      return Promise.resolve(jsonResult);
    }
  },
  "service/trade/common": {
    handleCards(arg) {		//认购期基金支持现金宝赎回转购
      let formData = arg[0];
      if(formData.businflag  == '020') {
        formData.moneyfundflag  = '1';
      }
	  	return formData;
    }
  },
  "components/fund/sdx": {
    changeCWarningBtns(arg) {		//修改适当性C类提示弹框的按钮文字
      let param = arg[0];
      let result = ["同意并继续", "取消交易"];
      param = result;
      return param;
    }
  },
  "view/risk/risk-test": {
    /**
     * 问卷预校验完成后，检查年龄，超过 60 岁或低于 18 岁时，会有二次确认弹框，允许直接重新测评。当重新测评时，返回 true，在页面中重新测评
     * @param {arrar} args 参数列表
     * @param {boolean} args[0] 第一个参数对应页面中的 testing，是否进入结束页面。为 false 时表示问卷题目结束
     */
    checkNeedRetest (args) {
      const riskResult = args[0];
      const riskability = parseInt(riskResult.accoRiskability);
      const riskablilityStr = riskResult.accoRiskabilityStr;
      return new Promise((resolve) => {
        if (riskability >= 3) {
          $.loading.start();
          $.service.queryAccoInfo(true).then((jsonResult) => {
            $.loading.stop();
            if (jsonResult.successful && jsonResult.accountInfo && jsonResult.accountInfo.age) {
              const age = parseInt(jsonResult.accountInfo.age);
              if (age && (age > 60 || age < 18)) {
                const primaryColor = $.config.primaryColor;
                const fontSize = `font-size:${  $.platform.isWeb() ? 13 : 15 }px;`
                const messageHtml = `
                <div style="flex-direction:row;padding-left:10px;padding-right:10px">
                  <span style="${fontSize}">您评测出的风险承受能力为</span>
                  <span style="color:${primaryColor};${fontSize}">${riskablilityStr}</span>
                  <span style="${fontSize}">，考虑到投资者年龄因素，建议您慎重考虑自身的风险承受能力</span>
                </div>
                </br>
                `
                const extraParam = $.platform.isWeb() ? {} : { messageHeight: 150 }; // APP 端才要手动设置 height，H5 会自动设置

                $.confirm({
                  type: "none",
                  html: messageHtml,
                  ...extraParam 
                }, [ "确认测评结果", "重新测评" ], () => {
                  resolve(false);
                }, () => {
                  resolve(true);
                });
              }
            } else {
              resolve(false);
            }
          })
        } else {
          resolve(false);
        }
      })
    },
    beforeDoRisk(arg) {
      const riskForm = arg[0];
      return new Promise((resolve) => {
        if ($.parseObjPath($, "config.extension.controlDoRiskTime", true) && riskForm.remain_num === "0") {
          $.alert({
            type: "none",
            title: '温馨提示',
            message: "您今日风险等级测评已达最大次数，不能再测评。",
          }, () => {
            $.route.hsBack();
          });
          resolve(false);
          return;
        }
        resolve(true);
      })
    }
  },
  "view/risk/risk-result": {
    beforeDoRisk(arg) {
      const accoInfo = arg[0];
      if ($.parseObjPath($, "config.extension.controlDoRiskTime", true) && accoInfo.remain_num === "0") {
        $.alert({
          type: "none",
          title: '温馨提示',
          message: "您今日风险等级测评已达最大次数，不能再测评。",
        });
        return false;
      }
      return true;
    }
  },
  "view/asset/componets/entry-info-disclosure-record": {
    // 修改信息披露记录列表页、修改信息披露记录详情页、修改资产详情页标题
    getTitle() {
      return "已阅读文件";
    }
  }
};

/**
 * 对外开放的调用函数
 * @param {Object} pageName 页面名称
 * @param {Object} funcName 个性化函数名称
 * @param {Object} defaultValue 默认返回值
 * @param {arg} defaultValue 个性化函数入参
 */
function call(pageName, funcName, defaultValue, ...arg) {
  if (service[pageName] && service[pageName][funcName]) {
    return service[pageName][funcName](arg);
  } else {
    if (typeof arg[1] === "function") {
      arg[1](defaultValue);
    }
    return defaultValue;
  }
}

export { call as newealthProjectExtend };
